﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "FastLine 클래스 사용하기";

            this.bufferingCheckBox.Checked  = true;
            this.drawAxisCheckBox.Checked   = true;
            this.clipPointsCheckBox.Checked = true;

            this.tChart.Graphics3D.BufferStyle = BufferStyle.OptimizedBuffer;
            this.tChart.Aspect.View3D          = false;
            this.tChart.Panel.Pen              = new ChartPen(Color.Black);
            this.tChart.Header.Visible         = false;
            this.tChart.Footer.Visible         = false;
            this.tChart.Legend.Visible         = false;

            FastLine fastLine1 = new FastLine(this.tChart.Chart);
            FastLine fastLine2 = new FastLine(this.tChart.Chart);

            Random random = new Random();

            for(int i = 1; i < 1000; i++)
            {
                int value = random.Next(Math.Abs(500 - i)) - (Math.Abs(500 - i) / 2);

                fastLine1.Add(1000 - i + value);
                fastLine2.Add(i + value       );
            }

            this.bufferingCheckBox.CheckedChanged  += bufferingCheckBox_CheckedChanged;
            this.drawAxisCheckBox.CheckedChanged   += drawAxisCheckBox_CheckedChanged;
            this.clipPointsCheckBox.CheckedChanged += clipPointsCheckBox_CheckedChanged;
            this.testSpeedButton.Click             += testSpeedButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 버퍼링 체크 박스 체크 변경시 처리하기 - bufferingCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 버퍼링 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void bufferingCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if(this.bufferingCheckBox.Checked)
            {
                this.tChart.Graphics3D.BufferStyle = BufferStyle.OptimizedBuffer;
            }
            else
            {
                this.tChart.Graphics3D.BufferStyle = BufferStyle.None;
            }
        }

        #endregion
        #region 축 그리기 체크 박스 체크 변경시 처리하기 - drawAxisCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 축 그리기 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void drawAxisCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.tChart.Axes.Visible = this.drawAxisCheckBox.Checked;
        }

        #endregion
        #region 포인트 클리핑 체크 박스 체크 변경시 처리하기 - clipPointsCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 포인트 클리핑 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void clipPointsCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.tChart.Aspect.ClipPoints = this.clipPointsCheckBox.Checked;
        }

        #endregion
        #region 속도 테스트 버튼 클릭시 처리하기 - testSpeedButton_Click(sender, e)

        /// <summary>
        /// 속도 테스트 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void testSpeedButton_Click(object sender, EventArgs e)
        {
            Cursor.Current = Cursors.WaitCursor;

            int markTime;

            try
            {
                this.tChart.Zoom.Animated = false;

                markTime = Environment.TickCount;

                for(int t = 1; t < 30; t++)
                {
                    this.tChart.Zoom.ZoomPercent(105);

                    this.tChart.Refresh();
                }

                for(int t = 1; t < 30; t++)
                {
                    this.tChart.Zoom.ZoomPercent(95);

                    this.tChart.Refresh(); 
                }

                markTime = Environment.TickCount - markTime;

                this.tChart.Zoom.Animated = true;

                this.tChart.Zoom.Undo();
            }
            finally
            {
                Cursor.Current = Cursors.Default;
            }

            MessageBox.Show($"2000개 점 찍은 시간\n61 번 : \n{markTime} 밀리초");
        }

        #endregion
    }
}